@@ -6,12 +6,14 @@ pub mod keys;
 pub use self::{genotype::Genotype, keys::Keys};
 
 use std::{
-    error, fmt,
+    error,
+    fmt::{self, Write},
     ops::{Deref, DerefMut},
     str::FromStr,
 };
 
 use self::genotype::field;
+use super::FIELD_DELIMITER;
 
 /// VCF record genotypes.
 #[derive(Clone, Debug, Default, PartialEq)]
@@ -47,11 +49,45 @@ impl Genotypes {
     }
 
     /// Returns the genotypes keys.
+    ///
+    /// # Examples
+    ///
+    /// ```
+    /// use noodles_vcf::record::{
+    ///     genotypes::{genotype::field::Key, Keys},
+    ///     Genotypes,
+    /// };
+    ///
+    /// let genotypes = Genotypes::default();
+    /// assert!(genotypes.keys().is_empty());
+    ///
+    /// let keys = Keys::try_from(vec![Key::Genotype])?;
+    /// let genotypes = Genotypes::new(keys.clone(), Vec::new());
+    /// assert_eq!(genotypes.keys(), &keys);
+    /// # Ok::<_, noodles_vcf::record::genotypes::keys::TryFromKeyVectorError>(())
+    /// ```
     pub fn keys(&self) -> &Keys {
         &self.keys
     }
 
     /// Returns a mutable reference to the genotypes keys.
+    ///
+    /// # Examples
+    ///
+    /// ```
+    /// use noodles_vcf::record::{
+    ///     genotypes::{genotype::field::Key, Keys},
+    ///     Genotypes,
+    /// };
+    ///
+    /// let keys = Keys::try_from(vec![Key::Genotype])?;
+    ///
+    /// let mut genotypes = Genotypes::default();
+    /// *genotypes.keys_mut() = keys.clone();
+    ///
+    /// assert_eq!(genotypes.keys(), &keys);
+    /// # Ok::<_, noodles_vcf::record::genotypes::keys::TryFromKeyVectorError>(())
+    /// ```
     pub fn keys_mut(&mut self) -> &mut Keys {
         &mut self.keys
     }
@@ -80,11 +116,11 @@ impl DerefMut for Genotypes {
 
 impl fmt::Display for Genotypes {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
-        write!(f, "{}\t", self.keys())?;
+        write!(f, "{}{}", self.keys(), FIELD_DELIMITER)?;
 
         for (i, genotype) in self.genotypes.iter().enumerate() {
             if i > 0 {
-                write!(f, "\t")?;
+                f.write_char(FIELD_DELIMITER)?;
             }
 
             write!(f, "{}", genotype)?;
@@ -124,8 +160,6 @@ impl FromStr for Genotypes {
     type Err = ParseError;
 
     fn from_str(s: &str) -> Result<Self, Self::Err> {
-        use super::FIELD_DELIMITER;
-
         if s.is_empty() {
             return Err(ParseError::Empty);
         }
@@ -136,7 +170,7 @@ impl FromStr for Genotypes {
 
         let genotypes = t
             .split(FIELD_DELIMITER)
-            .map(|t| Genotype::from_str_format(t, &keys))
+            .map(|t| Genotype::from_str_keys(t, &keys))
             .collect::<Result<_, _>>()
             .map_err(ParseError::InvalidGenotype)?;
 
@@ -152,10 +186,10 @@ mod tests {
     fn test_genotypes() -> Result<(), Box<dyn std::error::Error>> {
         let keys = "GT:GQ".parse()?;
         let genotypes = vec![
-            Genotype::from_str_format("0|0:7", &keys)?,
-            Genotype::from_str_format("./.:20", &keys)?,
-            Genotype::from_str_format("1/1:1", &keys)?,
-            Genotype::from_str_format(".", &keys)?,
+            Genotype::from_str_keys("0|0:7", &keys)?,
+            Genotype::from_str_keys("./.:20", &keys)?,
+            Genotype::from_str_keys("1/1:1", &keys)?,
+            Genotype::from_str_keys(".", &keys)?,
         ];
         let genotypes = Genotypes::new(keys, genotypes);
 
